@@ -33,12 +33,6 @@
  */
 #define CLIENT_CLEAN_UP_TIME  300
 
-struct TrackerDBusRequestHandler {
-	TrackerDBusRequestFunc new;
-	TrackerDBusRequestFunc done;
-	gpointer               user_data;
-};
-
 typedef struct {
 	gchar *sender;
 	gchar *binary;
@@ -47,6 +41,11 @@ typedef struct {
 	guint clean_up_id;
 } ClientData;
 
+struct _TrackerDBusRequest {
+	guint request_id;
+	ClientData *cd;
+};
+
 typedef struct {
 	GInputStream *unix_input_stream;
 	GInputStream *buffered_input_stream;
@@ -57,9 +56,6 @@ typedef struct {
 	gboolean expect_variable_names;
 } SendAndSpliceData;
 
-static GSList *hooks;
-static gboolean block_hooks;
-
 static gboolean client_lookup_enabled;
 static DBusGConnection *freedesktop_connection;
 static DBusGProxy *freedesktop_proxy;
@@ -68,46 +64,6 @@ static GHashTable *clients;
 static void     client_data_free    (gpointer data);
 static gboolean client_clean_up_cb (gpointer data);
 
-static void
-request_handler_call_for_new (guint request_id)
-{
-	GSList *l;
-
-	if (block_hooks) {
-		return;
-	}
-
-	for (l = hooks; l; l = l->next) {
-		TrackerDBusRequestHandler *handler;
-
-		handler = l->data;
-
-		if (handler->new) {
-			(handler->new)(request_id, handler->user_data);
-		}
-	}
-}
-
-static void
-request_handler_call_for_done (guint request_id)
-{
-	GSList *l;
-
-	if (block_hooks) {
-		return;
-	}
-
-	for (l = hooks; l; l = l->next) {
-		TrackerDBusRequestHandler *handler;
-
-		handler = l->data;
-
-		if (handler->done) {
-			(handler->done)(request_id, handler->user_data);
-		}
-	}
-}
-
 static gboolean
 clients_init (void)
 {
@@ -247,8 +203,8 @@ client_clean_up_cb (gpointer data)
 
 	cd = data;
 
-	g_debug ("Removing D-Bus client data for '%s' with id:'%s'",
-	         cd->binary, cd->sender);
+	g_debug ("Removing D-Bus client data for '%s' (pid: %lu) with id:'%s'",
+	         cd->binary, cd->pid, cd->sender);
 	g_hash_table_remove (clients, cd->sender);
 
 	if (g_hash_table_size (clients) < 1) {
@@ -260,10 +216,9 @@ client_clean_up_cb (gpointer data)
 }
 
 static ClientData *
-client_get_for_context (DBusGMethodInvocation *context)
+client_get_for_sender (const gchar *sender)
 {
 	ClientData *cd;
-	gchar *sender;
 
 	if (!client_lookup_enabled) {
 		return NULL;
@@ -272,25 +227,22 @@ client_get_for_context (DBusGMethodInvocation *context)
 	/* Only really done with tracker-extract where we use
 	 * functions from the command line with dbus code in them.
 	 */
-	if (!context) {
+	if (!sender) {
 		return NULL;
 	}
 
-	/* Shame we have to allocate memory in any condition here,
-	 * sucky glib D-Bus API is to blame here :/
-	 */
-	sender = dbus_g_method_get_sender (context);
-
 	if (G_UNLIKELY (!clients)) {
 		clients_init ();
 	}
 
 	cd = g_hash_table_lookup (clients, sender);
 	if (!cd) {
-		cd = client_data_new (sender);
-		g_hash_table_insert (clients, sender, cd);
+		gchar *sender_dup;
+
+		sender_dup = g_strdup (sender);
+		cd = client_data_new (sender_dup);
+		g_hash_table_insert (clients, sender_dup, cd);
 	} else {
-		g_free (sender);
 		g_source_remove (cd->clean_up_id);
 	}
 
@@ -301,46 +253,12 @@ client_get_for_context (DBusGMethodInvocation *context)
 	return cd;
 }
 
-GValue *
-tracker_dbus_gvalue_slice_new (GType type)
-{
-	GValue *value;
-
-	value = g_slice_new0 (GValue);
-	g_value_init (value, type);
-
-	return value;
-}
-
-void
-tracker_dbus_gvalue_slice_free (GValue *value)
-{
-	g_value_unset (value);
-	g_slice_free (GValue, value);
-}
-
 GQuark
 tracker_dbus_error_quark (void)
 {
 	return g_quark_from_static_string (TRACKER_DBUS_ERROR_DOMAIN);
 }
 
-TrackerDBusData *
-tracker_dbus_data_new (const gpointer arg1,
-                       const gpointer arg2)
-{
-	TrackerDBusData *data;
-
-	data = g_new0 (TrackerDBusData, 1);
-
-	data->id = tracker_dbus_get_next_request_id ();
-
-	data->data1 = arg1;
-	data->data2 = arg2;
-
-	return data;
-}
-
 gchar **
 tracker_dbus_slist_to_strv (GSList *list)
 {
@@ -365,151 +283,20 @@ tracker_dbus_slist_to_strv (GSList *list)
 	return strv;
 }
 
-gchar **
-tracker_dbus_str_to_strv (const gchar *str)
-{
-	gchar **strv;
-
-	strv = g_new (gchar*, 2);
-	strv[0] = g_strdup (str);
-	strv[1] = NULL;
-
-	return strv;
-}
-
-gchar **
-tracker_dbus_queue_str_to_strv (GQueue *queue,
-                                gint    max)
-{
-	gchar **strv;
-	gchar  *str;
-	gint    i, j;
-	gint    length;
-
-	length = g_queue_get_length (queue);
-
-	if (max > 0) {
-		length = MIN (max, length);
-	}
-
-	strv = g_new0 (gchar*, length + 1);
-
-	for (i = 0, j = 0; i < length; i++) {
-		str = g_queue_pop_head (queue);
-
-		if (!str) {
-			break;
-		}
-
-		if (!g_utf8_validate (str, -1, NULL)) {
-			g_message ("Could not add string:'%s' to GStrv, invalid UTF-8", str);
-			g_free (str);
-			continue;
-		}
-
-		strv[j++] = str;
-	}
-
-	strv[j] = NULL;
-
-	return strv;
-}
-
-gchar **
-tracker_dbus_queue_gfile_to_strv (GQueue *queue,
-                                  gint    max)
-{
-	gchar **strv;
-	gchar  *str;
-	GFile  *file;
-	gint    i, j;
-	gint    length;
-
-	length = g_queue_get_length (queue);
-
-	if (max > 0) {
-		length = MIN (max, length);
-	}
-
-	strv = g_new0 (gchar*, length + 1);
-
-	for (i = 0, j = 0; i < length; i++) {
-		file = g_queue_pop_head (queue);
-
-		if (!file) {
-			break;
-		}
-
-		str = g_file_get_path (file);
-		g_object_unref (file);
-
-		if (!g_utf8_validate (str, -1, NULL)) {
-			g_message ("Could not add string:'%s' to GStrv, invalid UTF-8", str);
-			g_free (str);
-			continue;
-		}
-
-		strv[j++] = str;
-	}
-
-	strv[j] = NULL;
-
-	return strv;
-}
-
-void
-tracker_dbus_results_ptr_array_free (GPtrArray **ptr_array)
-{
-	if (!ptr_array || !(*ptr_array)) {
-		return;
-	}
-
-	g_ptr_array_foreach (*ptr_array, (GFunc) g_strfreev, NULL);
-	g_ptr_array_free (*ptr_array, TRUE);
-	*ptr_array = NULL;
-}
-
-guint
-tracker_dbus_get_next_request_id (void)
+static guint
+get_next_request_id (void)
 {
 	static guint request_id = 1;
 
 	return request_id++;
 }
 
-TrackerDBusRequestHandler *
-tracker_dbus_request_add_hook (TrackerDBusRequestFunc new,
-                               TrackerDBusRequestFunc done,
-                               gpointer                       user_data)
+TrackerDBusRequest *
+tracker_dbus_request_begin (const gchar *sender,
+                            const gchar *format,
+                            ...)
 {
-	TrackerDBusRequestHandler *handler;
-
-	handler = g_slice_new0 (TrackerDBusRequestHandler);
-	handler->new = new;
-	handler->done = done;
-	handler->user_data = user_data;
-
-	hooks = g_slist_append (hooks, handler);
-
-	return handler;
-}
-
-void
-tracker_dbus_request_remove_hook (TrackerDBusRequestHandler *handler)
-{
-	g_return_if_fail (handler != NULL);
-
-	hooks = g_slist_remove (hooks, handler);
-	g_slice_free (TrackerDBusRequestHandler, handler);
-}
-
-void
-tracker_dbus_request_new (gint                   request_id,
-                          DBusGMethodInvocation *context,
-                          const gchar           *format,
-                          ...)
-{
-	ClientData *cd;
+	TrackerDBusRequest *request;
 	gchar *str;
 	va_list args;
 
@@ -517,78 +304,49 @@ tracker_dbus_request_new (gint                   request_id,
 	str = g_strdup_vprintf (format, args);
 	va_end (args);
 
-	cd = client_get_for_context (context);
+	request = g_slice_new (TrackerDBusRequest);
+	request->request_id = get_next_request_id ();
+	request->cd = client_get_for_sender (sender);
 
-	g_debug ("<--- [%d%s%s] %s",
-	         request_id,
-	         cd ? "|" : "",
-	         cd ? cd->binary : "",
+	g_debug ("<--- [%d%s%s|%lu] %s",
+	         request->request_id,
+	         request->cd ? "|" : "",
+	         request->cd ? request->cd->binary : "",
+	         request->cd ? request->cd->pid : 0,
 	         str);
 
 	g_free (str);
 
-	request_handler_call_for_new (request_id);
+	return request;
 }
 
 void
-tracker_dbus_request_success (gint                   request_id,
-                              DBusGMethodInvocation *context)
+tracker_dbus_request_end (TrackerDBusRequest *request,
+                          GError             *error)
 {
-	ClientData *cd;
-
-	request_handler_call_for_done (request_id);
-
-	cd = client_get_for_context (context);
-
-	g_debug ("---> [%d%s%s] Success, no error given",
-	         request_id,
-	         cd ? "|" : "",
-	         cd ? cd->binary : "");
-}
-
-void
-tracker_dbus_request_failed (gint                    request_id,
-                             DBusGMethodInvocation  *context,
-                             GError                **error,
-                             const gchar            *format,
-                             ...)
-{
-	ClientData *cd;
-	gchar *str;
-	va_list args;
-
-	request_handler_call_for_done (request_id);
-
-	if (format) {
-		va_start (args, format);
-		str = g_strdup_vprintf (format, args);
-		va_end (args);
-
-		g_set_error (error, TRACKER_DBUS_ERROR, 0, "%s", str);
-	} else if (*error != NULL) {
-		str = g_strdup ((*error)->message);
+	if (!error) {
+		g_debug ("---> [%d%s%s|%lu] Success, no error given",
+			 request->request_id,
+			 request->cd ? "|" : "",
+			 request->cd ? request->cd->binary : "",
+			 request->cd ? request->cd->pid : 0);
 	} else {
-		str = g_strdup (_("No error given"));
-		g_warning ("Unset error and no error message.");
+		g_message ("---> [%d%s%s|%lu] Failed, %s",
+			   request->request_id,
+			   request->cd ? "|" : "",
+			   request->cd ? request->cd->binary : "",
+			   request->cd ? request->cd->pid : 0,
+			   error->message);
 	}
 
-	cd = client_get_for_context (context);
-
-	g_message ("---> [%d%s%s] Failed, %s",
-	           request_id,
-	           cd ? "|" : "",
-	           cd ? cd->binary : "",
-	           str);
-	g_free (str);
+	g_slice_free (TrackerDBusRequest, request);
 }
 
 void
-tracker_dbus_request_info (gint                   request_id,
-                           DBusGMethodInvocation *context,
+tracker_dbus_request_info (TrackerDBusRequest    *request,
                            const gchar           *format,
                            ...)
 {
-	ClientData *cd;
 	gchar *str;
 	va_list args;
 
@@ -596,23 +354,20 @@ tracker_dbus_request_info (gint                   request_id,
 	str = g_strdup_vprintf (format, args);
 	va_end (args);
 
-	cd = client_get_for_context (context);
-
-	tracker_info ("---- [%d%s%s] %s",
-	              request_id,
-	              cd ? "|" : "",
-	              cd ? cd->binary : "",
+	tracker_info ("---- [%d%s%s|%lu] %s",
+	              request->request_id,
+	              request->cd ? "|" : "",
+	              request->cd ? request->cd->binary : "",
+	              request->cd ? request->cd->pid : 0,
 	              str);
 	g_free (str);
 }
 
 void
-tracker_dbus_request_comment (gint                   request_id,
-                              DBusGMethodInvocation *context,
+tracker_dbus_request_comment (TrackerDBusRequest    *request,
                               const gchar           *format,
                               ...)
 {
-	ClientData *cd;
 	gchar *str;
 	va_list args;
 
@@ -620,23 +375,20 @@ tracker_dbus_request_comment (gint                   request_id,
 	str = g_strdup_vprintf (format, args);
 	va_end (args);
 
-	cd = client_get_for_context (context);
-
-	g_message ("---- [%d%s%s] %s",
-	           request_id,
-	           cd ? "|" : "",
-	           cd ? cd->binary : "",
+	g_message ("---- [%d%s%s|%lu] %s",
+	           request->request_id,
+	           request->cd ? "|" : "",
+	           request->cd ? request->cd->binary : "",
+	           request->cd ? request->cd->pid : 0,
 	           str);
 	g_free (str);
 }
 
 void
-tracker_dbus_request_debug (gint                   request_id,
-                            DBusGMethodInvocation *context,
+tracker_dbus_request_debug (TrackerDBusRequest    *request,
                             const gchar           *format,
                             ...)
 {
-	ClientData *cd;
 	gchar *str;
 	va_list args;
 
@@ -644,28 +396,15 @@ tracker_dbus_request_debug (gint                   request_id,
 	str = g_strdup_vprintf (format, args);
 	va_end (args);
 
-	cd = client_get_for_context (context);
-
-	g_debug ("---- [%d%s%s] %s",
-	         request_id,
-	         cd ? "|" : "",
-	         cd ? cd->binary : "",
+	g_debug ("---- [%d%s%s|%lu] %s",
+	         request->request_id,
+	         request->cd ? "|" : "",
+	         request->cd ? request->cd->binary : "",
+	         request->cd ? request->cd->pid : 0,
 	         str);
 	g_free (str);
 }
 
-void
-tracker_dbus_request_block_hooks (void)
-{
-	block_hooks = TRUE;
-}
-
-void
-tracker_dbus_request_unblock_hooks (void)
-{
-	block_hooks = FALSE;
-}
-
 void
 tracker_dbus_enable_client_lookup (gboolean enabled)
 {
@@ -679,6 +418,30 @@ tracker_dbus_enable_client_lookup (gboolean enabled)
 	client_lookup_enabled = enabled;
 }
 
+TrackerDBusRequest *
+tracker_dbus_g_request_begin (DBusGMethodInvocation *context,
+                              const gchar           *format,
+                              ...)
+{
+	TrackerDBusRequest *request;
+	gchar *str, *sender;
+	va_list args;
+
+	va_start (args, format);
+	str = g_strdup_vprintf (format, args);
+	va_end (args);
+
+	sender = dbus_g_method_get_sender (context);
+
+	request = tracker_dbus_request_begin (sender, "%s", str);
+
+	g_free (sender);
+
+	g_free (str);
+
+	return request;
+}
+
 static GStrv
 dbus_send_and_splice_get_variable_names (DBusMessage *message,
                                          gboolean     copy_strings)
