@@ -41,6 +41,7 @@
 #include <libtracker-common/tracker-power.h>
 #include <libtracker-common/tracker-type-utils.h>
 #include <libtracker-common/tracker-utils.h>
+#include <libtracker-common/tracker-file-utils.h>
 
 #include <libtracker-data/tracker-db-manager.h>
 
@@ -803,7 +804,7 @@ set_up_mount_point (TrackerMinerFiles *miner,
 	} else {
 		tracker_sparql_connection_update_async (tracker_miner_get_connection (TRACKER_MINER (miner)),
                                                         queries->str,
-                                                        G_PRIORITY_DEFAULT,
+                                                        G_PRIORITY_LOW,
                                                         NULL,
                                                         set_up_mount_point_cb,
                                                         g_strdup (removable_device_urn));
@@ -998,7 +999,7 @@ init_mount_points (TrackerMinerFiles *miner_files)
 	if (accumulator->str[0] != '\0') {
 		tracker_sparql_connection_update_async (tracker_miner_get_connection (miner),
                                                         accumulator->str,
-                                                        G_PRIORITY_DEFAULT,
+                                                        G_PRIORITY_LOW,
                                                         NULL,
                                                         init_mount_points_cb,
                                                         miner);
@@ -1163,7 +1164,7 @@ mount_point_added_cb (TrackerStorage *storage,
 	set_up_mount_point_type (miner, urn, removable, optical, queries);
 	tracker_sparql_connection_update_async (tracker_miner_get_connection (TRACKER_MINER (miner)),
                                                 queries->str,
-                                                G_PRIORITY_DEFAULT,
+                                                G_PRIORITY_LOW,
                                                 NULL,
                                                 set_up_mount_point_cb,
                                                 g_strdup (urn));
@@ -1325,9 +1326,9 @@ mount_pre_unmount_cb (GVolumeMonitor    *volume_monitor,
 static gboolean
 disk_space_check (TrackerMinerFiles *mf)
 {
-	struct statvfs st;
 	gint limit;
 	gchar *data_dir;
+	gdouble remaining;
 
 	limit = tracker_config_get_low_disk_space_limit (mf->private->config);
 
@@ -1335,20 +1336,15 @@ disk_space_check (TrackerMinerFiles *mf)
 		return FALSE;
 	}
 
+	/* Get % of remaining space in the partition where the cache is */
 	data_dir = g_build_filename (g_get_user_cache_dir (), "tracker", NULL);
-
-	if (statvfs (data_dir, &st) == -1) {
-		g_warning ("Could not statvfs() '%s'", data_dir);
-		g_free (data_dir);
-		return FALSE;
-	}
-
+	remaining = tracker_file_system_get_remaining_space_percentage (data_dir);
 	g_free (data_dir);
 
-	if (((long long) st.f_bavail * 100 / st.f_blocks) <= limit) {
-		g_message ("WARNING: Available disk space is below configured "
-		           "threshold for acceptable working (%d%%)",
-		           limit);
+	if (remaining <= limit) {
+		g_message ("WARNING: Available disk space (%lf%%) is below "
+		           "configured threshold for acceptable working (%d%%)",
+		           remaining, limit);
 		return TRUE;
 	}
 
@@ -2267,36 +2263,43 @@ process_file_attributes_cb (GObject      *object,
 		return;
 	}
 
-	/* DELETE old property values */
+	/* Update nfo:fileLastModified */
 	tracker_sparql_builder_delete_open (sparql, NULL);
 	tracker_sparql_builder_subject_iri (sparql, urn);
 	tracker_sparql_builder_predicate (sparql, "nfo:fileLastModified");
 	tracker_sparql_builder_object_variable (sparql, "lastmodified");
-	tracker_sparql_builder_predicate (sparql, "nfo:fileLastAccessed");
-	tracker_sparql_builder_object_variable (sparql, "lastaccessed");
 	tracker_sparql_builder_delete_close (sparql);
-
 	tracker_sparql_builder_where_open (sparql);
 	tracker_sparql_builder_subject_iri (sparql, urn);
 	tracker_sparql_builder_predicate (sparql, "nfo:fileLastModified");
 	tracker_sparql_builder_object_variable (sparql, "lastmodified");
-	tracker_sparql_builder_predicate (sparql, "nfo:fileLastAccessed");
-	tracker_sparql_builder_object_variable (sparql, "lastaccessed");
 	tracker_sparql_builder_where_close (sparql);
-
-	/* INSERT new property values */
 	tracker_sparql_builder_insert_open (sparql, NULL);
 	tracker_sparql_builder_graph_open (sparql, TRACKER_MINER_FS_GRAPH_URN);
 	tracker_sparql_builder_subject_iri (sparql, urn);
-
 	time_ = g_file_info_get_attribute_uint64 (file_info, G_FILE_ATTRIBUTE_TIME_MODIFIED);
 	tracker_sparql_builder_predicate (sparql, "nfo:fileLastModified");
 	tracker_sparql_builder_object_date (sparql, (time_t *) &time_);
+	tracker_sparql_builder_graph_close (sparql);
+	tracker_sparql_builder_insert_close (sparql);
 
+	/* Update nfo:fileLastAccessed */
+	tracker_sparql_builder_delete_open (sparql, NULL);
+	tracker_sparql_builder_subject_iri (sparql, urn);
+	tracker_sparql_builder_predicate (sparql, "nfo:fileLastAccessed");
+	tracker_sparql_builder_object_variable (sparql, "lastaccessed");
+	tracker_sparql_builder_delete_close (sparql);
+	tracker_sparql_builder_where_open (sparql);
+	tracker_sparql_builder_subject_iri (sparql, urn);
+	tracker_sparql_builder_predicate (sparql, "nfo:fileLastAccessed");
+	tracker_sparql_builder_object_variable (sparql, "lastaccessed");
+	tracker_sparql_builder_where_close (sparql);
+	tracker_sparql_builder_insert_open (sparql, NULL);
+	tracker_sparql_builder_graph_open (sparql, TRACKER_MINER_FS_GRAPH_URN);
+	tracker_sparql_builder_subject_iri (sparql, urn);
 	time_ = g_file_info_get_attribute_uint64 (file_info, G_FILE_ATTRIBUTE_TIME_ACCESS);
 	tracker_sparql_builder_predicate (sparql, "nfo:fileLastAccessed");
 	tracker_sparql_builder_object_date (sparql, (time_t *) &time_);
-
 	tracker_sparql_builder_graph_close (sparql);
 	tracker_sparql_builder_insert_close (sparql);
 
@@ -2471,28 +2474,20 @@ tracker_miner_files_check_file (GFile  *file,
                                 GSList *ignored_file_paths,
                                 GSList *ignored_file_patterns)
 {
-	GFileInfo *file_info;
 	GSList *l;
 	gchar *basename;
 	gchar *path;
 	gboolean should_process;
 
-	file_info = NULL;
 	should_process = FALSE;
 	basename = NULL;
 	path = NULL;
 
-	file_info = g_file_query_info (file,
-	                               G_FILE_ATTRIBUTE_STANDARD_IS_HIDDEN,
-	                               G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
-	                               NULL, NULL);
-
-	if (file_info && g_file_info_get_is_hidden (file_info)) {
+	if (tracker_file_is_hidden (file)) {
 		/* Ignore hidden files */
 		goto done;
 	}
 
-
 	path = g_file_get_path (file);
 
 	for (l = ignored_file_paths; l; l = l->next) {
@@ -2515,10 +2510,6 @@ done:
 	g_free (basename);
 	g_free (path);
 
-	if (file_info) {
-		g_object_unref (file_info);
-	}
-
 	return should_process;
 }
 
@@ -2529,7 +2520,6 @@ tracker_miner_files_check_directory (GFile  *file,
                                      GSList *ignored_directory_paths,
                                      GSList *ignored_directory_patterns)
 {
-	GFileInfo *file_info;
 	GSList *l;
 	gchar *basename;
 	gchar *path;
@@ -2539,18 +2529,12 @@ tracker_miner_files_check_directory (GFile  *file,
 	should_process = FALSE;
 	basename = NULL;
 
-	/* Most common things to ignore */
-	file_info = g_file_query_info (file,
-	                               G_FILE_ATTRIBUTE_STANDARD_IS_HIDDEN,
-	                               G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
-	                               NULL, NULL);
-
 	path = g_file_get_path (file);
 
 	/* First we check the GIO hidden check. This does a number of
 	 * things for us which is good (like checking ".foo" dirs).
 	 */
-	is_hidden = file_info && g_file_info_get_is_hidden (file_info);
+	is_hidden = tracker_file_is_hidden (file);
 
 #ifdef __linux__
 	/* Second we check if the file is on FAT and if the hidden
@@ -2612,10 +2596,6 @@ tracker_miner_files_check_directory (GFile  *file,
 	g_free (basename);
 	g_free (path);
 
-	if (file_info) {
-		g_object_unref (file_info);
-	}
-
 	return should_process;
 }
 
@@ -2723,7 +2703,7 @@ miner_files_in_removable_media_remove_by_type (TrackerMinerFiles  *miner,
 
 		tracker_sparql_connection_update_async (tracker_miner_get_connection (TRACKER_MINER (miner)),
                                                         queries->str,
-                                                        G_PRIORITY_DEFAULT,
+                                                        G_PRIORITY_LOW,
                                                         NULL,
                                                         remove_files_in_removable_media_cb,
                                                         NULL);
@@ -2765,7 +2745,7 @@ miner_files_in_removable_media_remove_by_date (TrackerMinerFiles  *miner,
 
 	tracker_sparql_connection_update_async (tracker_miner_get_connection (TRACKER_MINER (miner)),
                                                 queries->str,
-                                                G_PRIORITY_DEFAULT,
+                                                G_PRIORITY_LOW,
                                                 NULL,
                                                 remove_files_in_removable_media_cb,
                                                 NULL);
