@@ -31,10 +31,8 @@ G_BEGIN_DECLS
 gboolean tracker_dbus_init             (void);
 void     tracker_dbus_shutdown         (void);
 gboolean tracker_dbus_register_objects (gpointer object);
-#ifdef HAVE_DBUS_FD_PASSING
 gboolean tracker_dbus_connection_add_filter (DBusHandleMessageFunction  function,
                                              void                      *user_data);
-#endif /* HAVE_DBUS_FD_PASSING */
 GObject *tracker_dbus_get_object       (GType    type);
 
 G_END_DECLS
